[tor-commits] [chutney/master] Increase start time to 20 seconds to avoid rare network failures

teor at torproject.org teor at torproject.org
Thu Jul 28 05:47:49 UTC 2016


commit bad7c3e8e4cbb3d276e01b0853eaef39baac8667
Author: teor (Tim Wilson-Brown) <teor2345 at gmail.com>
Date:   Thu Jul 28 15:39:06 2016 +1000

    Increase start time to 20 seconds to avoid rare network failures
    
    Older and slower versions of tor can't quite bootstrap in 15 seconds.
    (At least on slow machines.)
---
 README                | 4 ++--
 tools/test-network.sh | 6 +++---
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/README b/README
index a8024fa..f720a81 100644
--- a/README
+++ b/README
@@ -89,9 +89,9 @@ HS Connection Tests:
 Waiting for the network:
 
   The tools/test-network.sh script waits CHUTNEY_START_TIME seconds
-  (default: 15) before calling chutney verify, because that's the minimum
+  (default: 20) before calling chutney verify, because that's the minimum
   amount of time it takes to bootstrap a consensus containing relays.
-  (It takes 5 seconds for the authorities to create the first consensus,
+  (It takes 5-10 seconds for the authorities to create the first consensus,
   then 10 seconds for relays to bootstrap, submit their descriptors, and be
   included in the next consensus.) If CHUTNEY_START_TIME is negative, the
   script leaves the network running, and exits immediately (without verifying).
diff --git a/tools/test-network.sh b/tools/test-network.sh
index 4f1fdbe..0c5fdeb 100755
--- a/tools/test-network.sh
+++ b/tools/test-network.sh
@@ -177,11 +177,11 @@ fi
 cd "$CHUTNEY_PATH"
 ./tools/bootstrap-network.sh "$NETWORK_FLAVOUR" || exit 2
 
 # chutney starts verifying after 15 seconds, keeps on trying for 60 seconds,
 # and then stops immediately (by default)
-# Even the fastest chutney networks take 5 seconds for their first consensus
+# Even the fastest chutney networks take 5-10 seconds for their first consensus
 # and then 10 seconds after that for relays to bootstrap and upload descriptors
-CHUTNEY_START_TIME=${CHUTNEY_START_TIME:-15}
+CHUTNEY_START_TIME=${CHUTNEY_START_TIME:-20}
 CHUTNEY_BOOTSTRAP_TIME=${CHUTNEY_BOOTSTRAP_TIME:-60}
 CHUTNEY_STOP_TIME=${CHUTNEY_STOP_TIME:-0}
 
@@ -177,11 +177,11 @@ fi
 ./tools/bootstrap-network.sh "$NETWORK_FLAVOUR" || exit 2
 
-# chutney starts verifying after 15 seconds, keeps on trying for 60 seconds,
+# chutney starts verifying after 20 seconds, keeps on trying for 60 seconds,
 # and then stops immediately (by default)





More information about the tor-commits mailing list